# Issues
When you find any problems or have requests for new features, please first check to ensure that there is no duplicate issues already posted.
We usually use Japanese for internal development, but we are more than happy to communicate with you in English.

## Bug report
A bug report should briefly summarize the following details:
* What the bug is
* Steps to reproduce the bug
* What you expected to happen
* The execution environment

## Feature request

A feature request should briefly summarize the following details:

- If a bug is relevant, what it is
- What new features do you want to achieve
- Description of the implementation you consider
